import { IRenderingEngine } from "@shapediver/viewer.rendering-engine.rendering-engine";
import { ITreeNode } from "@shapediver/viewer.shared.node-tree";
import { Color } from "@shapediver/viewer.shared.types";
import { vec3 } from "gl-matrix";
import { ILightScene } from "../interface/ILightScene";
import { AbstractLight } from "./AbstractLight";
import { AmbientLight } from "./types/AmbientLight";
import { DirectionalLight } from "./types/DirectionalLight";
import { HemisphereLight } from "./types/HemisphereLight";
import { PointLight } from "./types/PointLight";
import { SpotLight } from "./types/SpotLight";
export declare class LightScene implements ILightScene {
    private readonly _renderingEngine;
    private readonly _id;
    private readonly _lights;
    private readonly _node;
    private _name;
    private _update?;
    constructor(_renderingEngine: IRenderingEngine, properties: {
        id: string;
        name?: string;
    });
    get id(): string;
    get lights(): {
        [key: string]: AbstractLight;
    };
    get name(): string | undefined;
    set name(value: string | undefined);
    get node(): ITreeNode;
    get update(): (() => void) | undefined;
    set update(value: (() => void) | undefined);
    addAmbientLight(properties: {
        color?: Color;
        intensity?: number;
        name?: string;
    }): AmbientLight;
    addDirectionalLight(properties: {
        color?: Color;
        intensity?: number;
        direction?: vec3;
        castShadow?: boolean;
        shadowMapResolution?: number;
        shadowMapBias?: number;
        name?: string;
    }): DirectionalLight;
    addHemisphereLight(properties: {
        color?: Color;
        intensity?: number;
        groundColor?: Color;
        name?: string;
    }): HemisphereLight;
    addLight(light: AbstractLight): void;
    addPointLight(properties: {
        color?: Color;
        intensity?: number;
        position?: vec3;
        distance?: number;
        decay?: number;
        name?: string;
    }): PointLight;
    addSpotLight(properties: {
        color?: Color;
        intensity?: number;
        position?: vec3;
        target?: vec3;
        distance?: number;
        decay?: number;
        angle?: number;
        penumbra?: number;
        name?: string;
    }): SpotLight;
    removeLight(id: string): boolean;
}
//# sourceMappingURL=LightScene.d.ts.map